from __future__ import print_function
from __future__ import absolute_import
from __future__ import division

from compas.geometry._primitives import Primitive

__all__ = ['Spline']


class Spline(Primitive):
    """"""

    def __init__(self):
        self.segments = []


# ==============================================================================
# Main
# ==============================================================================

if __name__ == '__main__':

    pass
